Projects per language
=====================

This page lists all projects found by searching 'gnucash' on github (generated on 2020-10-24 18:49:09) excluding mirrors of the gnucash repository. Projects with a '\*' are projectsthat have not been updated since 12 months.

+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     Language                     |                  # of projects                   |     # of projects updated in last 12 months      |
+==================================================+==================================================+==================================================+
|                  :ref:`Python`                   |                       173                        |                        85                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Unknown`                  |                        60                        |                        17                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Java`                    |                        42                        |                        14                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`JavaScript`                 |                        24                        |                        12                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl`                    |                        25                        |                        8                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Ruby`                    |                        18                        |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Shell`                   |                        26                        |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C#`                     |                        11                        |                        6                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`Dockerfile`                 |                        11                        |                        6                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Scheme`                   |                        15                        |                        6                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Go`                     |                        10                        |                        4                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`PHP`                    |                        16                        |                        3                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Awk`                    |                        2                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Dart`                    |                        3                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|             :ref:`Jupyter Notebook`              |                        5                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`R`                     |                        2                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`TypeScript`                 |                        4                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C++`                    |                        6                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`CSS`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`HTML`                    |                        4                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Haskell`                  |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`Inno Setup`                 |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`PLSQL`                   |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl6`                   |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Rust`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Scala`                   |                        3                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Swift`                   |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`TSQL`                    |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Tcl`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|               :ref:`Visual Basic`                |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`XSLT`                    |                        4                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`C`                     |                        8                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Diff`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Elixir`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`F#`                     |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|              :ref:`Gettext Catalog`              |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Groovy`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Roff`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`SQLPL`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+

.. _Python:

Python
------

\* `accounting-reports <https://github.com/ebridges/accounting-reports>`__ by ebridges (last updated on  <10)
	Accounting reports for GNUCash.
\* `AceMoney-to-GnuCash <https://github.com/lowvoltage/AceMoney-to-GnuCash>`__ by lowvoltage (last updated on  <10)
	A quick and dirty script to convert an AceMoney .XML into a GnuCash .XML
\* `alchemy <https://github.com/zmoog/alchemy>`__ by zmoog (last updated on  <10)
	A very simple Gnucash-inspired web application
\* `asset-allocation <https://github.com/MisterY/asset-allocation>`__ by MisterY (last updated on  <10)
	Asset Allocation implementation in Python
`bank_to_qif <https://github.com/engdan77/bank_to_qif>`__ by engdan77 (last updated on  <10)
	Program for processing XML/XLS bank account exports into QIF-format supported by e.g. GnuCash developed in Python
`BankCSVtoQif <https://github.com/niknow/BankCSVtoQif>`__ by niknow (last updated on  <10)
	Converts csv files from a bank to qif and replaces descriptions and target accounts according to predefined customizable rules along the way. Intended to work as a tool for gnucash.
\* `beancount2gnucash <https://github.com/wolfm89/beancount2gnucash>`__ by wolfm89 (last updated on  <10)
	Convert Beancount ledger files to GnuCash compatible files
\* `cookthebooks <https://github.com/colemannugent/cookthebooks>`__ by colemannugent (last updated on  <10)
	A python3 based, gnucash to ledger converter
\* `CSV-pre-processor-for-GnuCash <https://github.com/hughgliderpilot/CSV-pre-processor-for-GnuCash>`__ by hughgliderpilot (last updated on  <10)
	Takes transaction CSV download from bank and adds Transfer Account column based on Description
`csv2cash <https://github.com/jrwrigh/csv2cash>`__ by jrwrigh (last updated on  <10)
	Python package for importing CSV files to GNUCash
\* `csv2mt940 <https://github.com/selva-di/csv2mt940>`__ by selva-di (last updated on  <10)
	convert Sparda-West-csv to mt940 for gnucash import
`django-openbudget <https://github.com/evandavey/django-openbudget>`__ by evandavey (last updated on  <10)
	Simple django-based personal budgeting app that sources data from GNUCash sqlite data files
`dkb2qif <https://github.com/mzur/dkb2qif>`__ by mzur (last updated on  <10)
	Convert a DKB CSV export to QIF
`DKB_to_GnuCash <https://github.com/ch3fk0mm7/DKB_to_GnuCash>`__ by ch3fk0mm7 (last updated on  <10)
	Die CSV die man aus dem DKB Online Banking exportiert kann enthält in mehreren Spalten Informationen, die in GnuCash in die Spalte "Beschreibung" sollen, damit die Kategorie der Buchung automatisch erkannt werden kann.
`dkcash <https://github.com/quazgar/dkcash>`__ by quazgar (last updated on  <10)
	Direktkreditverwaltung mit gnucash-Backend
\* `DnbNor2qif <https://github.com/djiti/DnbNor2qif>`__ by djiti (last updated on  <10)
	Turning DnbNor CSV files into GNUCash-compatible QIF files
\* `dollar <https://github.com/marcotmarcot/dollar>`__ by marcotmarcot (last updated on  <10)
	Check if the dollar exchange rate is the same on my Gnucash transactions and UOL
`dropcopy <https://github.com/juniorbl/dropcopy>`__ by juniorbl (last updated on  <10)
	A simple tool for GNOME to copy a given GnuCash file to a local dropbox directory whenever it is saved.
`exporterVolksbank_GNUCash <https://github.com/vspaceone/exporterVolksbank_GNUCash>`__ by vspaceone (last updated on  <10)
	(No description available)
\* `finance_convert <https://github.com/RincewindWizzard/finance_convert>`__ by RincewindWizzard (last updated on  <10)
	Convert from Paypal and Volksbank to gnucash using csv
\* `financial_forecast <https://github.com/skullspace/financial_forecast>`__ by skullspace (last updated on  <10)
	A script to take in our Gnucash books and output a CSV with some historical and forecasted data
`flux <https://github.com/marcotmarcot/flux>`__ by marcotmarcot (last updated on  <10)
	Create a monthly flux report from a gnucash file
\* `gcimport <https://github.com/nblock/gcimport>`__ by nblock (last updated on  <10)
	Convert various input files (csv, txt) to csv files that can be easily parsed with GnuCash.
`gcinvoice <https://github.com/ngiger/gcinvoice>`__ by ngiger (last updated on  <10)
	GnuCash to Lates (see http://www.smoerz.org/gcinvoice/) + my personal templates
\* `generate_prices <https://github.com/barrettTom/generate_prices>`__ by barrettTom (last updated on  <10)
	gnucash price database generator script
`gnc-fq-helper <https://github.com/yegord/gnc-fq-helper>`__ by yegord (last updated on  <10)
	A drop-in replacement for GnuCash's Finance::Quote helper
\* `gnc2QuickBooks <https://github.com/jfishe/gnc2QuickBooks>`__ by jfishe (last updated on  <10)
	Python 2 convert GnuCash to QuickBooks tab delimited import format
\* `gnc_budget_scroll <https://github.com/mateuszzz88/gnc_budget_scroll>`__ by mateuszzz88 (last updated on  <10)
	This is a converter for gnucash bugdet report. It will create html with the same content, but table will be scrollable in such way, that headers (date, account name) are visible
\* `gnc_privat24 <https://github.com/gentoo90/gnc_privat24>`__ by gentoo90 (last updated on  <10)
	Imports Privat24 statements to Gnucash book
`gnc_tools <https://github.com/armanschwarz/gnc_tools>`__ by armanschwarz (last updated on  <10)
	Python tools for validating GnuCash files
`gncxml <https://github.com/LiosK/gncxml>`__ by LiosK (last updated on  <10)
	gncxml - extract entries from GnuCash data file to pandas.DataFrame
\* `gnucash-account2template <https://github.com/EvansMike/gnucash-account2template>`__ by EvansMike (last updated on  <10)
	Make a GnuCash account template from an exported account
`gnucash-bridge <https://github.com/dbellettini/gnucash-bridge>`__ by dbellettini (last updated on  <10)
	Expose GnuCash as a microservice
\* `gnucash-budgerow- <https://github.com/dlex/gnucash-budgerow->`__ by dlex (last updated on  <10)
	Predictive budgeter for GnuCash
\* `gnucash-budget <https://github.com/chrisbrasington/gnucash-budget>`__ by chrisbrasington (last updated on  <10)
	Minimalist budget reporting.
\* `gnucash-categorizer <https://github.com/seddonym/gnucash-categorizer>`__ by seddonym (last updated on  <10)
	(No description available)
\* `gnucash-cfdi <https://github.com/sebastianavina/gnucash-cfdi>`__ by sebastianavina (last updated on  <10)
	Proyecto que timbra facturas de gnucash por medio de facturacion moderna.
\* `gnucash-cli <https://github.com/loftx/gnucash-cli>`__ by loftx (last updated on  <10)
	(No description available)
\* `GnuCash-CSV2CSV-for-PowerBi <https://github.com/aidancrane/GnuCash-CSV2CSV-for-PowerBi>`__ by aidancrane (last updated on  <10)
	I use this to convert my GnuCash csv exports for analysis in MS Power BI
`gnucash-csv2html <https://github.com/m13253/gnucash-csv2html>`__ by m13253 (last updated on  <10)
	Convert CSV files exported by GnuCash to HTML format
`gnucash-docs-rst <https://github.com/codesmythe/gnucash-docs-rst>`__ by codesmythe (last updated on  <10)
	GnuCash documentation in RestructuredText as Sphinx project
\* `gnucash-expense-report <https://github.com/QuLogic/gnucash-expense-report>`__ by QuLogic (last updated on  <10)
	(No description available)
`GnuCash-Expenses-Vis <https://github.com/maciek3000/GnuCash-Expenses-Vis>`__ by maciek3000 (last updated on  <10)
	Visualizations of Expenses created in GnuCash Accounting Software
`gnucash-fiximports <https://github.com/sandeepmukherjee/gnucash-fiximports>`__ by sandeepmukherjee (last updated on  <10)
	Change target accounts of imported gnucash transactions
`gnucash-fiximports <https://github.com/jamessherring/gnucash-fiximports>`__ by jamessherring (last updated on  <10)
	(No description available)
\* `gnucash-fiximports <https://github.com/HappyPeng2x/gnucash-fiximports>`__ by HappyPeng2x (last updated on  <10)
	Additional developments on the original gnucash-fiximports
\* `gnucash-gource-viz <https://github.com/C7C8/gnucash-gource-viz>`__ by C7C8 (last updated on  <10)
	Script to convert GNUCash transaction histories into logs that can be visualized by Gource (because why not?)
\* `gnucash-import <https://github.com/manzato/gnucash-import>`__ by manzato (last updated on  <10)
	Imports transactions from a CSV file and places them to the appropriate account depending on a set of rules
`gnucash-import-stock <https://github.com/senooken/gnucash-import-stock>`__ by senooken (last updated on  <10)
	(No description available)
`gnucash-importer <https://github.com/shaform/gnucash-importer>`__ by shaform (last updated on  <10)
	Utilities to import transactions into GnuCash
\* `gnucash-importer <https://github.com/gunny26/gnucash-importer>`__ by gunny26 (last updated on  <10)
	import some csv data, categorize bookings automatically with help of some neuronal network categorizer
`gnucash-importer <https://github.com/drjeep/gnucash-importer>`__ by drjeep (last updated on  <10)
	(No description available)
`gnucash-importers <https://github.com/rtucker/gnucash-importers>`__ by rtucker (last updated on  <10)
	gnucash importer scripts for Interlock Rochester financial foo
`gnucash-imports <https://github.com/dpslwk/gnucash-imports>`__ by dpslwk (last updated on  <10)
	Import scripts for Nottingham Hackspace GNUCash
`gnucash-input <https://github.com/elChapoSing/gnucash-input>`__ by elChapoSing (last updated on  <10)
	personal process for DBS input into gnucash compatible file format
\* `gnucash-inteligo <https://github.com/lukasszz/gnucash-inteligo>`__ by lukasszz (last updated on  <10)
	Importowanie wyciągów z Inteligo do Gnucash,
\* `gnucash-latex <https://github.com/mwellnitz/gnucash-latex>`__ by mwellnitz (last updated on  <10)
	Create good looking invoices for gnucash using latex and python
\* `gnucash-latex-koma <https://github.com/jappeace/gnucash-latex-koma>`__ by jappeace (last updated on  <10)
	 Create good looking invoices for gnucash using latex/koma and python 
`gnucash-mail-sync <https://github.com/omelkova/gnucash-mail-sync>`__ by omelkova (last updated on  <10)
	(No description available)
\* `gnucash-ofx-brokerage <https://github.com/7max/gnucash-ofx-brokerage>`__ by 7max (last updated on  <10)
	GnuCash OFX importer that handles brokerages, ie stocks, mutual funds, optios
`gnucash-ofx-export <https://github.com/hoffie/gnucash-ofx-export>`__ by hoffie (last updated on  <10)
	Selectively export GnuCash transactions into OFX
`gnucash-portfolio <https://github.com/MisterY/gnucash-portfolio>`__ by MisterY (last updated on  <10)
	Tools for managing an investment portfolio in a GnuCash book
\* `gnucash-portfolio-cli <https://github.com/MisterY/gnucash-portfolio-cli>`__ by MisterY (last updated on  <10)
	Gnucash Portfolio CLI
`gnucash-portfolio-webui <https://github.com/MisterY/gnucash-portfolio-webui>`__ by MisterY (last updated on  <10)
	GnuCash Portfolio Web UI
`gnucash-prices <https://github.com/nomis/gnucash-prices>`__ by nomis (last updated on  <10)
	GnuCash price database management
\* `gnucash-pyquotehist <https://github.com/tfree87/gnucash-pyquotehist>`__ by tfree87 (last updated on  <10)
	A simple python script which imports historical price quotes from yahoo into Gnucash via the command line without the need for Perl Finance::QuoteHist. Based on Peter Holtermann's quotes_hist script
\* `Gnucash-Python-Example <https://github.com/petarkabashki/Gnucash-Python-Example>`__ by petarkabashki (last updated on  <10)
	Example python script for importing data into Gnucash
\* `gnucash-python-free <https://github.com/tbhartman/gnucash-python-free>`__ by tbhartman (last updated on  <10)
	(No description available)
\* `GNUCash-Python-Scripts <https://github.com/relyt29/GNUCash-Python-Scripts>`__ by relyt29 (last updated on  <10)
	various python scripts to add to gnucash functionality
`gnucash-qif-import <https://github.com/hjacobs/gnucash-qif-import>`__ by hjacobs (last updated on  <10)
	GnuCash Python helper script to import transactions from QIF text files into GnuCash's own file format
`gnucash-reconciler <https://github.com/rmehyde/gnucash-reconciler>`__ by rmehyde (last updated on  <10)
	Tool for comparing Gnucash records to bank records automatically
`gnucash-reports <https://github.com/MeerkatLabs/gnucash-reports>`__ by MeerkatLabs (last updated on  <10)
	Simple reporting framework for fetching data out of gnucash files for display in a viewer.
`gnucash-rest <https://github.com/loftx/gnucash-rest>`__ by loftx (last updated on  <10)
	A Python based REST framework for the Gnucash accounting application
\* `gnucash-rest-docker <https://github.com/loftx/gnucash-rest-docker>`__ by loftx (last updated on  <10)
	A dockerfile and associated files to quickly test the Gnucash Rest API
\* `gnucash-savings <https://github.com/chrisbrasington/gnucash-savings>`__ by chrisbrasington (last updated on  <10)
	gnucash-savings projection
\* `GNUCash-scripts <https://github.com/spartha80/GNUCash-scripts>`__ by spartha80 (last updated on  <10)
	Simple Python scripts to convert Bank statements to QIF format
`gnucash-scripts <https://github.com/thomasrebele/gnucash-scripts>`__ by thomasrebele (last updated on  <10)
	(No description available)
`gnucash-select <https://github.com/bulletmark/gnucash-select>`__ by bulletmark (last updated on  <10)
	GnuCash File Selector
\* `gnucash-society <https://github.com/hendrikvanantwerpen/gnucash-society>`__ by hendrikvanantwerpen (last updated on  <10)
	Support application for societies based on GnuCash
`gnucash-stock-portfolio <https://github.com/hjacobs/gnucash-stock-portfolio>`__ by hjacobs (last updated on  <10)
	GnuCash Python utilities to manage a stock portfolio
`gnucash-stock-quotes <https://github.com/DrSkippy/gnucash-stock-quotes>`__ by DrSkippy (last updated on  <10)
	(No description available)
`gnucash-to-beancount <https://github.com/henriquebastos/gnucash-to-beancount>`__ by henriquebastos (last updated on  <10)
	Gnucash to Beancount Converter.
\* `gnucash-tools <https://github.com/cnuahs/gnucash-tools>`__ by cnuahs (last updated on  <10)
	Command line tools for use with Gnucash (http://gnucash.org/).
\* `gnucash-tools <https://github.com/yanivmo/gnucash-tools>`__ by yanivmo (last updated on  <10)
	GnuCash interoperability scripts
\* `gnucash-tools <https://github.com/dahnielson/gnucash-tools>`__ by dahnielson (last updated on  <10)
	💰 Tools for working with GnuCash
`gnucash-tools <https://github.com/iqt4/gnucash-tools>`__ by iqt4 (last updated on  <10)
	(No description available)
\* `gnucash-toolset <https://github.com/cirrax/gnucash-toolset>`__ by cirrax (last updated on  <10)
	Access and manipulate gnucash data.
\* `gnucash-util <https://github.com/bstpierre/gnucash-util>`__ by bstpierre (last updated on  <10)
	Utility scripts using GnuCash python bindings
`gnucash-utilities <https://github.com/sdementen/gnucash-utilities>`__ by sdementen (last updated on  <10)
	Set of python scripts to work with GnuCash books
\* `gnucash-utils <https://github.com/AndreasHeger/gnucash-utils>`__ by AndreasHeger (last updated on  <10)
	utility scripts for gnucash
`gnucash-vis <https://github.com/chrlen/gnucash-vis>`__ by chrlen (last updated on  <10)
	A script to visualize state of accounts from a Gnucash file exported by the client for Android
\* `gnucash-xml-split <https://github.com/fefe982/gnucash-xml-split>`__ by fefe982 (last updated on  <10)
	Split GnuCash XML files into files containing transaction in a certain period (e.g. a year)
`gnucash2beancount <https://github.com/shaform/gnucash2beancount>`__ by shaform (last updated on  <10)
	(No description available)
`gnucash2googlesheets <https://github.com/erikvanegmond/gnucash2googlesheets>`__ by erikvanegmond (last updated on  <10)
	(No description available)
\* `gnucash2iif <https://github.com/pawl/gnucash2iif>`__ by pawl (last updated on  <10)
	Converts a Gnucash general ledger to an IIF file (for quickbooks)
\* `gnucash_autobudget <https://github.com/rmoehn/gnucash_autobudget>`__ by rmoehn (last updated on  <10)
	Automatically adjust GnuCash transactions for envelope budgeting (discontinued)
\* `gnucash_balance_report <https://github.com/tbhartman/gnucash_balance_report>`__ by tbhartman (last updated on  <10)
	get balance report from gnucash file
\* `gnucash_budget <https://github.com/dschwen/gnucash_budget>`__ by dschwen (last updated on  <10)
	Tools to work with a GnuCash database
\* `gnucash_converter <https://github.com/boszkie/gnucash_converter>`__ by boszkie (last updated on  <10)
	python script to convert rabobank (nl) csv format to gnuCash csv import format
\* `gnucash_django <https://github.com/RobFisher/gnucash_django>`__ by RobFisher (last updated on  <10)
	GnuCash Web Interface using Django.
\* `gnucash_envelope_assist <https://github.com/MarkOfLark/gnucash_envelope_assist>`__ by MarkOfLark (last updated on  <10)
	Scripts that assist in using GnuCash for personal finances under the envelope system
`gnucash_explorer <https://github.com/peap/gnucash_explorer>`__ by peap (last updated on  <10)
	Another option for exploring your gnucash database
\* `gnucash_exports <https://github.com/jjuanda/gnucash_exports>`__ by jjuanda (last updated on  <10)
	GnuCash export scripts into several DBs/file formats
`gnucash_general_journal <https://github.com/dorfsmay/gnucash_general_journal>`__ by dorfsmay (last updated on  <10)
	GnuCash csv General Journal
\* `gnucash_import_from_bank <https://github.com/silvester747/gnucash_import_from_bank>`__ by silvester747 (last updated on  <10)
	Convert bank statements in a format GNUCash can import.
`gnucash_import_util <https://github.com/shinnkondo/gnucash_import_util>`__ by shinnkondo (last updated on  <10)
	(No description available)
`gnucash_invoice_automator <https://github.com/peanutbutterandcrackers/gnucash_invoice_automator>`__ by peanutbutterandcrackers (last updated on  <10)
	I haz the power of Libreoffice Calc and python-gnucash on my side
\* `gnucash_lbb_amazon <https://github.com/elezar/gnucash_lbb_amazon>`__ by elezar (last updated on  <10)
	Amazon Credit Card CSV pre-processor for GNUCash
\* `gnucash_magical_importer <https://github.com/foguinhoperuca/gnucash_magical_importer>`__ by foguinhoperuca (last updated on  <10)
	Set of scripts to manage my personal finance with gnucash
\* `gnucash_ofx <https://github.com/gevious/gnucash_ofx>`__ by gevious (last updated on  <10)
	Convert gnucash xml file to set of OFX files
\* `gnucash_quotes <https://github.com/belidzs/gnucash_quotes>`__ by belidzs (last updated on  <10)
	Download stock and currency quotes from Alpha Vantage and save it to GnuCash
`gnucash_tweaks <https://github.com/jokim/gnucash_tweaks>`__ by jokim (last updated on  <10)
	Simple ad hoc tweaks, because I don't have time to learn to code inside GnuCash
\* `gnucashApi <https://github.com/f-angi/gnucashApi>`__ by f-angi (last updated on  <10)
	(No description available)
\* `GnuCashImporter <https://github.com/sphaero/GnuCashImporter>`__ by sphaero (last updated on  <10)
	Simple console tool to import mt940 file and match transactions to GnuCash accounts
`gnucashpricesupdater <https://github.com/danfcosta/gnucashpricesupdater>`__ by danfcosta (last updated on  <10)
	Update prices of Brazilian commodities on GnuCash database (SQLite)
`gnucashreconcile <https://github.com/seddonym/gnucashreconcile>`__ by seddonym (last updated on  <10)
	(No description available)
`gnucashreport <https://github.com/partizand/gnucashreport>`__ by partizand (last updated on  <10)
	Python library for get reports from GnuCash to xlsx files
\* `GnucashReporting <https://github.com/sholly/GnucashReporting>`__ by sholly (last updated on  <10)
	Python/Flask backend for gnucash reports
`gnucashreports <https://github.com/youngchul/gnucashreports>`__ by youngchul (last updated on  <10)
	(No description available)
`gnucashREST <https://github.com/f-angi/gnucashREST>`__ by f-angi (last updated on  <10)
	A REST(ful) API for basic GnuCash operations
\* `GNUCashTools <https://github.com/s8002sid/GNUCashTools>`__ by s8002sid (last updated on  <10)
	This repository will be used for storing GNUCash tools
\* `gnuCashTools <https://github.com/Walms/gnuCashTools>`__ by Walms (last updated on  <10)
	Just a few scripts to help manage my budget
\* `GnuCashUtils <https://github.com/wlcasper/GnuCashUtils>`__ by wlcasper (last updated on  <10)
	GnuCash scripts
`gnucashxml <https://github.com/jorgenschaefer/gnucashxml>`__ by jorgenschaefer (last updated on  <10)
	New Maintainer, please use their repository
\* `hackerspace-gnucash <https://github.com/cvonkleist/hackerspace-gnucash>`__ by cvonkleist (last updated on  <10)
	Gainesville Hackerspace GnuCash scripts, etc.
\* `importfindata <https://github.com/gregorias/importfindata>`__ by gregorias (last updated on  <10)
	Script that updates Polish investment fund quotes in a Gnucash file.
\* `ing2gnucash <https://github.com/hjmeijer/ing2gnucash>`__ by hjmeijer (last updated on  <10)
	Converts downloaded ING (bank) transaction CSV files to GNUCash importable CSV
\* `ing2qif <https://github.com/marijnvriens/ing2qif>`__ by marijnvriens (last updated on  <10)
	Import ING bank statements and convert them to qif for importing into gnucash
`ing2qif2 <https://github.com/tychobismeijer/ing2qif2>`__ by tychobismeijer (last updated on  <10)
	Convert ING csv to QIF format for GnuCash
`jeffs-gnucash-utils <https://github.com/n1ywb/jeffs-gnucash-utils>`__ by n1ywb (last updated on  <10)
	Jeff Laughlin's Python utilities for GnuCash. Includes HTML invoice generator.
`koert <https://github.com/awesterb/koert>`__ by awesterb (last updated on  <10)
	Toolbox for the inspection of GnuCash (used by the financial control committee of Karpe Noktem).
`ledger-explorer <https://github.com/saufrecht/ledger-explorer>`__ by saufrecht (last updated on  <10)
	Navigate any¹ hierarchical ledger graphically, all the way down to individual transactions.  (¹ as long as it's formatted exactly like a Gnucash CSV export)
\* `ledger2gnucash <https://github.com/dotmjs/ledger2gnucash>`__ by dotmjs (last updated on  <10)
	Simple python script to convert ledger-cli files to GnuCash
\* `mint2gnucash <https://github.com/SAL-e/mint2gnucash>`__ by SAL-e (last updated on  <10)
	Use mint.com together with GnuCash.
\* `Mint2GNUCash <https://github.com/alexevans91/Mint2GNUCash>`__ by alexevans91 (last updated on  <10)
	Converts transaction CSV file from Mint.com to a format that can be imported into GNU Cash.
`mintcash <https://github.com/hiromu2000/mintcash>`__ by hiromu2000 (last updated on  <10)
	Transfer transactions from Mint.com to Gnucash
\* `moneyguru-to-gnucash <https://github.com/peppelan/moneyguru-to-gnucash>`__ by peppelan (last updated on  <10)
	Data migration from Moneyguru to GnuCash made easy
`mwrr <https://github.com/jmtilli/mwrr>`__ by jmtilli (last updated on  <10)
	Money-weighted rate of return calculator for GnuCash
\* `NokiaCash <https://github.com/sunziping2016/NokiaCash>`__ by sunziping2016 (last updated on  <10)
	A GnuCash-like software on S60v3 developed by python
`ofxstatement <https://github.com/kedder/ofxstatement>`__ by kedder (last updated on  <10)
	Tool to convert proprietary bank statement to OFX format, suitable for importing to GnuCash or other personal finance applications.
`ofxstatement-al_bank <https://github.com/lbschenkel/ofxstatement-al_bank>`__ by lbschenkel (last updated on  <10)
	Arbejdernes Landsbank plugin for ofxstatement
\* `ofxstatement-lansforsakringar <https://github.com/lbschenkel/ofxstatement-lansforsakringar>`__ by lbschenkel (last updated on  <10)
	Länsförsakringar plugin for ofxstatement
`ofxstatement-sparkasse-freiburg <https://github.com/omarkohl/ofxstatement-sparkasse-freiburg>`__ by omarkohl (last updated on  <10)
	ofxstatement plugin for the German bank Sparkasse Freiburg-Nördlicher Breisgau
`pdf2gc <https://github.com/iqt4/pdf2gc>`__ by iqt4 (last updated on  <10)
	Read bank statement and import into Gnucash
`piecash <https://github.com/sdementen/piecash>`__ by sdementen (last updated on  <10)
	Pythonic interface to GnuCash SQL documents
\* `pricedb-pull <https://github.com/chrisberkhout/pricedb-pull>`__ by chrisberkhout (last updated on  <10)
	Pull historical prices for use in GnuCash and Ledger CLI
\* `PyBank <https://github.com/dougthor42/PyBank>`__ by dougthor42 (last updated on  <10)
	Personal accounting software. Alternative to the likes of Quicken, iBank, Mint.com, and GnuCash
`pycash <https://github.com/ellevset/pycash>`__ by ellevset (last updated on  <10)
	Python gnucash coupling
`pycash <https://github.com/ellevset/pycash>`__ by ellevset (last updated on  <10)
	Python gnucash coupling
`pygnc <https://github.com/ErwinRieger/pygnc>`__ by ErwinRieger (last updated on  <10)
	My Gnucash extensions for german small businesses using gnucash and aqbanking python-api's (ibr-gnc-module reloaded).
`pygnclib <https://github.com/tdf/pygnclib>`__ by tdf (last updated on  <10)
	Pyxb-based read and write support for GnuCash XML files
`pygnucash <https://github.com/MatzeB/pygnucash>`__ by MatzeB (last updated on  <10)
	Python code to read gnucash 2.6 sqlite3 files; features gnucash 2 ledger translator.
`pyGnuCash <https://github.com/sebgad/pyGnuCash>`__ by sebgad (last updated on  <10)
	Python Access for GnuCash
`pyTry <https://github.com/EpistemikPython/pyTry>`__ by EpistemikPython (last updated on  <10)
	parse Monarch report files and create transactions to write to a Gnucash file
\* `qb2gnc <https://github.com/jfishe/qb2gnc>`__ by jfishe (last updated on  <10)
	Python 2 convert QuickBooks to GnuCash
`qif-split <https://github.com/ebridges/qif-split>`__ by ebridges (last updated on  <10)
	Splits transactions in a QIF file to support budgeting and more granular financial tracking.
`qifqif <https://github.com/Kraymer/qifqif>`__ by Kraymer (last updated on  <10)
	Enrich your .QIF files with categories.
`rabo2ofx <https://github.com/gbonnema/rabo2ofx>`__ by gbonnema (last updated on  <10)
	A python script to convert Dutch Rabobank CSV files to OFX files for processing in GnuCash.
`rabobank-gnucash-converter <https://github.com/boterbloem5/rabobank-gnucash-converter>`__ by boterbloem5 (last updated on  <10)
	(No description available)
`scripts <https://github.com/cpg314/scripts>`__ by cpg314 (last updated on  <10)
	Collection of Python scripts
`simple_gnucash_budget_plots <https://github.com/csun/simple_gnucash_budget_plots>`__ by csun (last updated on  <10)
	Simple budget plots for GnuCash - discussed in https://www.csun.io/2020/05/17/gnucash-finance.html
`skr-json <https://github.com/baltpeter/skr-json>`__ by baltpeter (last updated on  <10)
	GnuCash account templates (Standard-Kontenrahmen) JSON
`small_scripts <https://github.com/sercxanto/small_scripts>`__ by sercxanto (last updated on  <10)
	Simple scripts too small for own repo
`square_transaction_parser <https://github.com/rwslippey/square_transaction_parser>`__ by rwslippey (last updated on  <10)
	A simple script to help prepare square transaction csv data for import to accounting software like GNUCash
\* `text-messaging-to-gnucash <https://github.com/chrisbrasington/text-messaging-to-gnucash>`__ by chrisbrasington (last updated on  <10)
	Create transactions via commandline text-messaging to gnucash sqlite database.
\* `Timetracker-to-Gnucash-Invoice <https://github.com/EvansMike/Timetracker-to-Gnucash-Invoice>`__ by EvansMike (last updated on  <10)
	Takes Anuko Timetracker data and creates an Invoice in GnuCash
\* `tws-gnucash <https://github.com/twswn/tws-gnucash>`__ by twswn (last updated on  <10)
	(No description available)
`UpdateBudgetQtrly <https://github.com/EpistemikPython/UpdateBudgetQtrly>`__ by EpistemikPython (last updated on  <10)
	gnucash and google functions to update my BudgetQtrly document
`visa-parser <https://github.com/pguridi/visa-parser>`__ by pguridi (last updated on  <10)
	A parser for the Visa pdf bill from www.visa.com.ar, useful for CSV import in Gnucash.
\* `volksbank-csv-to-gnucash-csv-converter <https://github.com/Kaedo/volksbank-csv-to-gnucash-csv-converter>`__ by Kaedo (last updated on  <10)
	(No description available)
`webgnucash <https://github.com/donautech/webgnucash>`__ by donautech (last updated on  <10)
	Server for web version of GnuCash 
\* `WestpacGNUCashManager <https://github.com/jakeb1996/WestpacGNUCashManager>`__ by jakeb1996 (last updated on  <10)
	Export your Westpac transactions in QIF format and prepare them for GnuCash
\* `zoysia <https://github.com/honthion/zoysia>`__ by honthion (last updated on  <10)
	gnucash项目后台 python flask

.. _Awk:

Awk
---

`credit-card-statement-reconciler <https://github.com/icyflame/credit-card-statement-reconciler>`__ by icyflame (last updated on  <10)
	      Scripts to reconcile your credit card statement with your manually maintained accounts from GnuCash
`ibank2qif <https://github.com/tomszilagyi/ibank2qif>`__ by tomszilagyi (last updated on  <10)
	Bank account transactions into GnuCash

.. _C:

C
-

\* `gnc-balcheck <https://github.com/prebbz/gnc-balcheck>`__ by prebbz (last updated on  <10)
	Quickly get the balance of a GnuCash which uses a MySQL backend
\* `gnucash-2 <https://github.com/kleopatra999/gnucash-2>`__ by kleopatra999 (last updated on  <10)
	Yet another clone of the gnucash source code
\* `gnucash-aqplus <https://github.com/jhs-s/gnucash-aqplus>`__ by jhs-s (last updated on  <10)
	Usually contains some fixes for aqbanking for GnuCash
\* `Gnucash-gnucash <https://github.com/jimmymccord/Gnucash-gnucash>`__ by jimmymccord (last updated on  <10)
	(No description available)
\* `gnucash-jz-snap <https://github.com/jacobzimmermann/gnucash-jz-snap>`__ by jacobzimmermann (last updated on  <10)
	(No description available)
\* `gnucash-svn <https://github.com/kleopatra999/gnucash-svn>`__ by kleopatra999 (last updated on  <10)
	another clone of gnucash, but this time not using github's clone, and therefore keeping the svn metadata
\* `gnucash_python <https://github.com/davidjo/gnucash_python>`__ by davidjo (last updated on  <10)
	gnucash report writing in python
\* `tk_gnucash3.3-python <https://github.com/tkerns1965/tk_gnucash3.3-python>`__ by tkerns1965 (last updated on  <10)
	(No description available)

.. _C#:

C#
--

`bank2qif <https://github.com/piontec/bank2qif>`__ by piontec (last updated on  <10)
	A companion project for https://www.gnucash.org/. Helps import bank statements to GnuCash.
`BudgetApp <https://github.com/Lakendary/BudgetApp>`__ by Lakendary (last updated on  <10)
	Budget web application for GnuCash
\* `CS320GnuCashTesting <https://github.com/BrookJacob/CS320GnuCashTesting>`__ by BrookJacob (last updated on  <10)
	Repository for the testing of GnuCash for CS320
\* `FinanceWeb <https://github.com/elohmeier/FinanceWeb>`__ by elohmeier (last updated on  <10)
	C#/.NET OData Adapter for reading GnuCash Databases with MSFT Excel
\* `gnucash2ledger-cli <https://github.com/marek-g/gnucash2ledger-cli>`__ by marek-g (last updated on  <10)
	Gnucash (general ledger html report) to ledger-cli converter.
`GnuCash2Qif <https://github.com/Jason-Carter/GnuCash2Qif>`__ by Jason-Carter (last updated on  <10)
	Convert GnuCash Sqlite database to QIF format
`GnuCashCSLib <https://github.com/kiranvr/GnuCashCSLib>`__ by kiranvr (last updated on  <10)
	A C# library to read values from GNUCash xml files.
\* `GnuCashDotNetAPI <https://github.com/SolidDynamics/GnuCashDotNetAPI>`__ by SolidDynamics (last updated on  <10)
	A .NET API for GnuCash using the C API https://wiki.gnucash.org/wiki/Using_the_API
\* `GnuCashParser <https://github.com/nikitazu/GnuCashParser>`__ by nikitazu (last updated on  <10)
	.Net parser for GnuCash files format
`GnucashPlDataImportGenerator <https://github.com/AdrianS-PL/GnucashPlDataImportGenerator>`__ by AdrianS-PL (last updated on  <10)
	(No description available)
`GnuCashSharp <https://github.com/rstarkov/GnuCashSharp>`__ by rstarkov (last updated on  <10)
	A library for reading data from GnuCash XML files.

.. _C++:

C++
---

\* `gnucash-butchered <https://github.com/iulianu/gnucash-butchered>`__ by iulianu (last updated on  <10)
	My own butchered version of Gnucash
\* `gnuCash-price-upload <https://github.com/gavin-blakeman/gnuCash-price-upload>`__ by gavin-blakeman (last updated on  <10)
	Upload .csv files to gnuCash prices
\* `gnuCash-pud <https://github.com/gavin-blakeman/gnuCash-pud>`__ by gavin-blakeman (last updated on  <10)
	Commodity Price Upload Daemon for gnuCash
\* `gnutreemfc <https://github.com/edkirkman/gnutreemfc>`__ by edkirkman (last updated on  <10)
	gnucash using MFC GUI and MySQL backend
`investmentManager <https://github.com/gavin-blakeman/investmentManager>`__ by gavin-blakeman (last updated on  <10)
	Web Based Application to complement gnuCash and provide management and user interface to manage mutual funds
\* `UnderBudget <https://github.com/vimofthevine/UnderBudget>`__ by vimofthevine (last updated on  <10)
	Advanced personal budget analysis application that integrates with GnuCash, Quicken, mint.com, etc.

.. _CSS:

CSS
---

`gnucash_gtk3 <https://github.com/davidschmitt/gnucash_gtk3>`__ by davidschmitt (last updated on  <10)
	GTK3 CSS for customizing GnuCash appearance

.. _Dart:

Dart
----

`dartcash <https://github.com/sandeep84/dartcash>`__ by sandeep84 (last updated on  <10)
	Dartlang implementation of GNUCash sqlite format file support.
\* `gnucash-flutter <https://github.com/pefdow/gnucash-flutter>`__ by pefdow (last updated on  <10)
	Flutter implementation of gnucash-android 
`moneybags <https://github.com/sandeep84/moneybags>`__ by sandeep84 (last updated on  <10)
	A GNUCash viewer application.

.. _Diff:

Diff
----

\* `GnuCash-Windows-Fixes <https://github.com/theochino/GnuCash-Windows-Fixes>`__ by theochino (last updated on  <10)
	Pieces needed to Compile Gnu Cash on a Windows machine ... http://wiki.gnucash.org/wiki/User:Bilkusg

.. _Dockerfile:

Dockerfile
----------

`docker-gnucash <https://github.com/mhitchens/docker-gnucash>`__ by mhitchens (last updated on  <10)
	GnuCash running via X11 over SSH
\* `docker-gnucash <https://github.com/HodeiG/docker-gnucash>`__ by HodeiG (last updated on  <10)
	docker-gnucash
\* `docker-gnucash <https://github.com/Caveja/docker-gnucash>`__ by Caveja (last updated on  <10)
	Docker container with GnuCash built from source
\* `docker-gnucash-novnc <https://github.com/bertlorenz/docker-gnucash-novnc>`__ by bertlorenz (last updated on  <10)
	(No description available)
`gnucash-dev-docker <https://github.com/diablodale/gnucash-dev-docker>`__ by diablodale (last updated on  <10)
	Docker containers for automated OS setup and dev/build environ for gnucash v3+ binaries and docs
`gnucash-docker <https://github.com/aitor3ml/gnucash-docker>`__ by aitor3ml (last updated on  <10)
	dockerized gnucash
`gnucash-docker <https://github.com/mtbkapp/gnucash-docker>`__ by mtbkapp (last updated on  <10)
	Run gnucash in docker with tigervnc and novnc for access from browser.
`gnucash-docker <https://github.com/mtbkapp/gnucash-docker>`__ by mtbkapp (last updated on  <10)
	Run gnucash in docker with tigervnc and novnc for access from browser.
`GNUCash-Docker-Build <https://github.com/crossan007/GNUCash-Docker-Build>`__ by crossan007 (last updated on  <10)
	Docker based build environment for GNUCash
`gnucash-docker-for-python <https://github.com/devbar/gnucash-docker-for-python>`__ by devbar (last updated on  <10)
	Container to provide working gnucash backend and python bindings
\* `ppa-gnucash-xbt <https://github.com/msvalina/ppa-gnucash-xbt>`__ by msvalina (last updated on  <10)
	Unofficial build of GnuCash with Bitcoin support for Ubuntu Bionic

.. _Elixir:

Elixir
------

\* `gca <https://github.com/arturmalecki/gca>`__ by arturmalecki (last updated on  <10)
	Extension for GnuCash

.. _F#:

F#
--

\* `gnucash-tools <https://github.com/cantsin/gnucash-tools>`__ by cantsin (last updated on  <10)
	(No description available)

.. _Gettext Catalog:

Gettext Catalog
---------------

\* `gnucash-el <https://github.com/pgaval/gnucash-el>`__ by pgaval (last updated on  <10)
	Automatically exported from code.google.com/p/gnucash-el

.. _Go:

Go
--

`bankcsv <https://github.com/lpenz/bankcsv>`__ by lpenz (last updated on  <10)
	Tool that I use to convert the CSV from banks to gnucash3-compatible transaction CSV
`coin <https://github.com/mkobetic/coin>`__ by mkobetic (last updated on  <10)
	heavily simplified version of ledger-cli.org with a twist (very much a work in progress)
\* `gnc-api-d <https://github.com/vinymeuh/gnc-api-d>`__ by vinymeuh (last updated on  <10)
	A read only REST server for GnuCash file
\* `gnucash-csv-exporter <https://github.com/andrepnh/gnucash-csv-exporter>`__ by andrepnh (last updated on  <10)
	Exports gnucash files to csv
`gnucash-graphql <https://github.com/vinymeuh/gnucash-graphql>`__ by vinymeuh (last updated on  <10)
	A GraphQL server for GnuCash files 
\* `gnucash-parser <https://github.com/xavier268/gnucash-parser>`__ by xavier268 (last updated on  <10)
	Parse Gnucash files in Go
\* `gnucash-viewer <https://github.com/mmbros/gnucash-viewer>`__ by mmbros (last updated on  <10)
	A gnucash file viewer
\* `gnucash-viewer-old <https://github.com/mmbros/gnucash-viewer-old>`__ by mmbros (last updated on  <10)
	(No description available)
\* `gocash <https://github.com/remyoudompheng/gocash>`__ by remyoudompheng (last updated on  <10)
	gocash is a personal accounting interface similar to gnucash
`p24fetch <https://github.com/tuxofil/p24fetch>`__ by tuxofil (last updated on  <10)
	Fetch transaction log from Privat24 for GnuCash

.. _Groovy:

Groovy
------

\* `Zio-Antunello <https://github.com/masokotanga/Zio-Antunello>`__ by masokotanga (last updated on  <10)
	un gnucash online (?)

.. _HTML:

HTML
----

\* `Gnucash-gnucash-htdocs <https://github.com/jimmymccord/Gnucash-gnucash-htdocs>`__ by jimmymccord (last updated on  <10)
	(No description available)
`gnucash-htdocs <https://github.com/Gnucash/gnucash-htdocs>`__ by Gnucash (last updated on  <10)
	GnuCash website.
\* `gnucash-jp <https://github.com/omoshetech/gnucash-jp>`__ by omoshetech (last updated on  <10)
	(No description available)
\* `gnucashkr.github.io <https://github.com/GnucashKr/gnucashkr.github.io>`__ by GnucashKr (last updated on  <10)
	gnucashkr.github.io 홈페이지 소스

.. _Haskell:

Haskell
-------

\* `hGnucash <https://github.com/pharaun/hGnucash>`__ by pharaun (last updated on  <10)
	Haskell xml library for parsing the gnucash file format
`hs-gnucash <https://github.com/knupfer/hs-gnucash>`__ by knupfer (last updated on  <10)
	Haskell library to work with gnucash

.. _Inno Setup:

Inno Setup
----------

`gnucash-on-windows <https://github.com/Gnucash/gnucash-on-windows>`__ by Gnucash (last updated on  <10)
	Support scripts to build gnucash for Windows using mingw32.

.. _Java:

Java
----

\* `accounting <https://github.com/milanogc/accounting>`__ by milanogc (last updated on  <10)
	This project is an attempt to create a GnuCash like system, i.e. it adopts the double entry bookkeeping accounting system, for the management of personal finances.
\* `android_search-recycler-cardview-learning-gnucash <https://github.com/cc-shifo/android_search-recycler-cardview-learning-gnucash>`__ by cc-shifo (last updated on  <10)
	(No description available)
\* `androidcash <https://github.com/mbarbon/androidcash>`__ by mbarbon (last updated on  <10)
	Simple Android GnuCash companion
`BackupGnuCashLinux <https://github.com/goodvibes2/BackupGnuCashLinux>`__ by goodvibes2 (last updated on  <10)
	Backup GnuCash for Linux (using openjdk + openjfx)
`BackupGnuCashMigor <https://github.com/goodvibes2/BackupGnuCashMigor>`__ by goodvibes2 (last updated on  <10)
	Backup GnuCash + Migor (my personal MS Access database)
`BackupGnuCashWin <https://github.com/goodvibes2/BackupGnuCashWin>`__ by goodvibes2 (last updated on  <10)
	Backup GnuCash for Windows (using javafx)
\* `barx <https://github.com/pgiu/barx>`__ by pgiu (last updated on  <10)
	Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
\* `barxm <https://github.com/pgiu/barxm>`__ by pgiu (last updated on  <10)
	Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
\* `BudgetReportGnuCash <https://github.com/martinlong1978/BudgetReportGnuCash>`__ by martinlong1978 (last updated on  <10)
	Jasper Budget Report for GnuCash
\* `convert-ingcsv-to-gnucash <https://github.com/jonaskoperdraat/convert-ingcsv-to-gnucash>`__ by jonaskoperdraat (last updated on  <10)
	Application to convert csv export from ING to a format GnuCash can import
\* `gcchart <https://github.com/jhogan/gcchart>`__ by jhogan (last updated on  <10)
	An website for reading GnuCash datasources and creating charts written in Java.
\* `gnc4a <https://github.com/bwduncan/gnc4a>`__ by bwduncan (last updated on  <10)
	GnuCash Companion for Android is an mobile application for devices running Google’s Android operating system, which will enable the users of GnuCash to do small things like adding a transaction or creating an invoice or expense voucher on the go.
\* `gnc4a <https://github.com/glennji/gnc4a>`__ by glennji (last updated on  <10)
	Gnucash for Android
\* `GncImport <https://github.com/fcuenca/GncImport>`__ by fcuenca (last updated on  <10)
	GnuCash transaction import tool
\* `GncXmlLib <https://github.com/fcuenca/GncXmlLib>`__ by fcuenca (last updated on  <10)
	A small library to manipulate GnuCash data in XML format
\* `GnuCash-2.6.5-importer <https://github.com/jan438/GnuCash-2.6.5-importer>`__ by jan438 (last updated on  <10)
	(No description available)
`gnucash-android <https://github.com/codinguser/gnucash-android>`__ by codinguser (last updated on  <10)
	Gnucash for Android mobile companion application. 
`gnucash-android <https://github.com/BattleCupcake/gnucash-android>`__ by BattleCupcake (last updated on  <10)
	(No description available)
`gnucash-android <https://github.com/yjkang0602/gnucash-android>`__ by yjkang0602 (last updated on  <10)
	(No description available)
`gnucash-android <https://github.com/yjkang0602/gnucash-android>`__ by yjkang0602 (last updated on  <10)
	(No description available)
`gnucash-android <https://github.com/nicxleo/gnucash-android>`__ by nicxleo (last updated on  <10)
	(No description available)
\* `gnucash-android-example <https://github.com/felipecmuniz/gnucash-android-example>`__ by felipecmuniz (last updated on  <10)
	(No description available)
`gnucash-merge <https://github.com/pnemonic78/gnucash-merge>`__ by pnemonic78 (last updated on  <10)
	Merge two gnucash XML files.
\* `gnucash-utils <https://github.com/crankydillo/gnucash-utils>`__ by crankydillo (last updated on  <10)
	(No description available)
`gnuCashAdaptors <https://github.com/yrado/gnuCashAdaptors>`__ by yrado (last updated on  <10)
	Scripts to make import to GnuCash simple
\* `GnuCashBudgetReport <https://github.com/bvitale/GnuCashBudgetReport>`__ by bvitale (last updated on  <10)
	A budget report for GnuCash data that is stored in MySQL.
\* `gnucashjgnash <https://github.com/leeboardtools/gnucashjgnash>`__ by leeboardtools (last updated on  <10)
	Plugin for jGnash that converts a (simple) GnuCash database to jGnash
\* `gnucashMobile <https://github.com/nhrdl/gnucashMobile>`__ by nhrdl (last updated on  <10)
	(No description available)
\* `gnuCashN <https://github.com/nyshthefantastic/gnuCashN>`__ by nyshthefantastic (last updated on  <10)
	(No description available)
\* `gnucashtest <https://github.com/krismess/gnucashtest>`__ by krismess (last updated on  <10)
	Automated test for Gnucash Android app
\* `GnuCashToQIF <https://github.com/davidkgerman/GnuCashToQIF>`__ by davidkgerman (last updated on  <10)
	(No description available)
\* `GnuCashViewer <https://github.com/jrmcsoftware/GnuCashViewer>`__ by jrmcsoftware (last updated on  <10)
	GnuCash Viewer
`IngAusOfxFixLinux <https://github.com/goodvibes2/IngAusOfxFixLinux>`__ by goodvibes2 (last updated on  <10)
	ING Australia OFX Fix for Linux - Fix OFX file before importing into GnuCash
`IngAusOfxFixWin <https://github.com/goodvibes2/IngAusOfxFixWin>`__ by goodvibes2 (last updated on  <10)
	ING Australia OFX Fix for Windows - Fix OFX file before importing into GnuCash
\* `javacash <https://github.com/nhrdl/javacash>`__ by nhrdl (last updated on  <10)
	Yet another implementation of gnucash in Java
`javacash <https://github.com/brentwalther/javacash>`__ by brentwalther (last updated on  <10)
	An application for managing money. Inspired by GnuCash.
\* `jgc <https://github.com/kevemueller/jgc>`__ by kevemueller (last updated on  <10)
	Java library to read GnuCash files
`jGnuCash2Qif <https://github.com/Jason-Carter/jGnuCash2Qif>`__ by Jason-Carter (last updated on  <10)
	Convert GnuCash Sqlite database to QIF format - the Java version
\* `jgnucashlib <https://github.com/tdf/jgnucashlib>`__ by tdf (last updated on  <10)
	jGnucashLib - a java access to GnuCash files
`Maakboekingen <https://github.com/zwijze/Maakboekingen>`__ by zwijze (last updated on  <10)
	Maakboekingen in gnucash
\* `nordea-to-gnucash <https://github.com/mohamedamer/nordea-to-gnucash>`__ by mohamedamer (last updated on  <10)
	(No description available)
\* `workspace_gnucash <https://github.com/won21kr1/workspace_gnucash>`__ by won21kr1 (last updated on  <10)
	(No description available)

.. _JavaScript:

JavaScript
----------

\* `bcqif <https://github.com/hugozap/bcqif>`__ by hugozap (last updated on  <10)
	Script simple para generar archivos QIF a partir de archivos .txt exportados desde Bancolombia y poder cargar los registros a programas como GnuCash
`cash-cow <https://github.com/Lkxz/cash-cow>`__ by Lkxz (last updated on  <10)
	A basic double-entry bookeping system, similar to GNUCash, written in Go and React.
`cashdash <https://github.com/mbugert/cashdash>`__ by mbugert (last updated on  <10)
	💰 Interactive visualization of GnuCash data based on plotly Dash.
\* `cashviz <https://github.com/nunofgl/cashviz>`__ by nunofgl (last updated on  <10)
	Visualizations for GNUCash data.
\* `finance_dashboard <https://github.com/manicolosi/finance_dashboard>`__ by manicolosi (last updated on  <10)
	A dashing dashboard to show financial information from GnuCash
`finquick <https://github.com/dckc/finquick>`__ by dckc (last updated on  <10)
	web app access to gnucash financial data
\* `gnucash-browser <https://github.com/phjardas/gnucash-browser>`__ by phjardas (last updated on  <10)
	Web Interface for GnuCash Ledgers
`gnucash-django <https://github.com/nylen/gnucash-django>`__ by nylen (last updated on  <10)
	Simple Web frontend for GnuCash, using Django
`gnucash-ppa <https://github.com/chenghlee/gnucash-ppa>`__ by chenghlee (last updated on  <10)
	Sources for the chenghlee/gnucash PPA
\* `gnucash-price-importer <https://github.com/cortopy/gnucash-price-importer>`__ by cortopy (last updated on  <10)
	Script for importing historic currency prices into gnucash
\* `gnucash-reporter <https://github.com/AaronLenoir/gnucash-reporter>`__ by AaronLenoir (last updated on  <10)
	Visualizes some reports on GnuCash data.
`gnucash-reporting-view <https://github.com/MeerkatLabs/gnucash-reporting-view>`__ by MeerkatLabs (last updated on  <10)
	Angular JS Based viewer for gnucash-reports
`gnucash-sql <https://github.com/wraithgar/gnucash-sql>`__ by wraithgar (last updated on  <10)
	Gnucash sqlite thingy
\* `gnucash-viewer <https://github.com/drjeep/gnucash-viewer>`__ by drjeep (last updated on  <10)
	Web viewer for Gnucash using Python/Flask
\* `gnucash-web <https://github.com/mrkrstphr/gnucash-web>`__ by mrkrstphr (last updated on  <10)
	(No description available)
\* `GnucashReportingNVD3 <https://github.com/sholly/GnucashReportingNVD3>`__ by sholly (last updated on  <10)
	NVD3 frontend/playground for gnucash reporting..
`monalyzer <https://github.com/Vlad-ku/monalyzer>`__ by Vlad-ku (last updated on  <10)
	Анализ файлов QIF (GnuCash)
\* `profitcash-restful <https://github.com/TheProfitwareGroup/profitcash-restful>`__ by TheProfitwareGroup (last updated on  <10)
	[DEPRECATED] ProfitCash-RESTful is a RESTful service providing accounts and transaction information based on imported from GnuCash into MongoDB data.
`qif-converter <https://github.com/matthijsmelissen/qif-converter>`__ by matthijsmelissen (last updated on  <10)
	Converts CSV files from ING (Netherlands) and BCEE (Luxembourg) into QIF files. Suitable for GnuCash.
`remotegnucash <https://github.com/justinhunt1223/remotegnucash>`__ by justinhunt1223 (last updated on  <10)
	Remote GnuCash
\* `salis <https://github.com/f0x52/salis>`__ by f0x52 (last updated on  <10)
	GNUCash alternative
\* `skilap <https://github.com/sergeyksv/skilap>`__ by sergeyksv (last updated on  <10)
	Personal online applications, GnuCash clone and others
`vue-gnucash <https://github.com/biker2000on/vue-gnucash>`__ by biker2000on (last updated on  <10)
	(No description available)
`webgnucash-client <https://github.com/donautech/webgnucash-client>`__ by donautech (last updated on  <10)
	Client part of Web version of GnuCash

.. _Jupyter Notebook:

Jupyter Notebook
----------------

`gnucash-historical-price-data <https://github.com/MichaelSchmidt82/gnucash-historical-price-data>`__ by MichaelSchmidt82 (last updated on  <10)
	Add historical stock price data to gnucash ledgers.
\* `gnucash-playground <https://github.com/nlzimmerman/gnucash-playground>`__ by nlzimmerman (last updated on  <10)
	Just playing around with OFX and gnucash files; I am presumably the only person who cares about this sort of things.
\* `gnucash_analysis <https://github.com/prattmic/gnucash_analysis>`__ by prattmic (last updated on  <10)
	Analyze GnuCash data with Pandas
`GnuCash_tools <https://github.com/PingWIn87/GnuCash_tools>`__ by PingWIn87 (last updated on  <10)
	My toolset for GnuCash
\* `py-gnucash <https://github.com/ihkihk/py-gnucash>`__ by ihkihk (last updated on  <10)
	Python scripts for analysis of gnucash database

.. _PHP:

PHP
---

\* `buchungen <https://github.com/jungepiraten/buchungen>`__ by jungepiraten (last updated on  <10)
	Webinterface für gnucash-Datenbank mit Funktion zum Verifizieren von Buchungen
\* `cash-manager <https://github.com/jUnG3/cash-manager>`__ by jUnG3 (last updated on  <10)
	(No description available)
\* `cashonline-php-server <https://github.com/okovalov/cashonline-php-server>`__ by okovalov (last updated on  <10)
	Backend part for cashonline project (clone of gnucash)
\* `gnucash-dashboard <https://github.com/bkrijg/gnucash-dashboard>`__ by bkrijg (last updated on  <10)
	(No description available)
\* `gnucash-eloquent <https://github.com/b3it/gnucash-eloquent>`__ by b3it (last updated on  <10)
	Laravel Eloquent Models for the GnuCash MySQL Backend
\* `gnucash-laravel <https://github.com/xstat/gnucash-laravel>`__ by xstat (last updated on  <10)
	(No description available)
\* `gnucash-php <https://github.com/cebe/gnucash-php>`__ by cebe (last updated on  <10)
	A library for reading gnucash XML format in PHP
\* `gnucash-reports <https://github.com/xstat/gnucash-reports>`__ by xstat (last updated on  <10)
	(No description available)
\* `gnucash-tools <https://github.com/cccmzwi/gnucash-tools>`__ by cccmzwi (last updated on  <10)
	Convert your onlinebanking-export (CSV) to a neatly pre-categorized QIF-File which can be imported in Quicken or Gnucash
\* `gnucash.cakephp <https://github.com/claudineimatos/gnucash.cakephp>`__ by claudineimatos (last updated on  <10)
	(No description available)
\* `gnucashreports <https://github.com/pedroabel/gnucashreports>`__ by pedroabel (last updated on  <10)
	Set of custom reports that I use for my personal finances. To see the reports working on a sample database, check the website http://gnucashreports.comuf.com/ ATTENTION: many problems yet. Many bugs that did not happen in my computer happened in this sample server.
\* `php-gnucash <https://github.com/mrkrstphr/php-gnucash>`__ by mrkrstphr (last updated on  <10)
	(No description available)
`PhpGnuCashMatchTransactions <https://github.com/puggan/PhpGnuCashMatchTransactions>`__ by puggan (last updated on  <10)
	Tool for GnuCash databases, to import and match up transactions from banks export-files
`plans-comptables-francais <https://github.com/Seb35/plans-comptables-francais>`__ by Seb35 (last updated on  <10)
	Plans comptables français aux formats CSV et GNUCash
\* `ThinkopenAt.Gnucash <https://github.com/kraftb/ThinkopenAt.Gnucash>`__ by kraftb (last updated on  <10)
	A TYPO3 Flow package which allows to interface the Gnucash book keeping application
`txs <https://github.com/vvvitaly/txs>`__ by vvvitaly (last updated on  <10)
	Export bills from different sources into Gnucash-like CSV

.. _PLSQL:

PLSQL
-----

`gnucash-mysql-additions <https://github.com/ohingardail/gnucash-mysql-additions>`__ by ohingardail (last updated on  <10)
	Custom MySql functions to add useful functions to GnuCash

.. _Perl:

Perl
----

\* `bsestocks <https://github.com/poomalairaj/bsestocks>`__ by poomalairaj (last updated on  <10)
	Perl module to fetch live price from Bombay Stock Exchange (BSE) for Gnucash Finance
\* `budgetProgram <https://github.com/Beahmer89/budgetProgram>`__ by Beahmer89 (last updated on  <10)
	Converts GNUCash programs xml output to csv file to see monthly/yearly spending habits
`Finance--Quote--YahooJapan <https://github.com/LiosK/Finance--Quote--YahooJapan>`__ by LiosK (last updated on  <10)
	Finance::Quote::YahooJapan - A Perl module that enables GnuCash to get quotes of Japanese stocks and mutual funds from Yahoo! Finance JAPAN.
\* `finance-bomse <https://github.com/abhijit86k/finance-bomse>`__ by abhijit86k (last updated on  <10)
	A Perl module for fetching quotes for Indian stocks, intended for use with gnucash
`finance-quote-brazil <https://github.com/romuloceccon/finance-quote-brazil>`__ by romuloceccon (last updated on  <10)
	Gnucash/Finance::Quote modules to fetch prices of Brazilian stocks, bonds and mutual funds
\* `FinanceQuoteBr <https://github.com/ailtonljr/FinanceQuoteBr>`__ by ailtonljr (last updated on  <10)
	Perl Finance Quote modules for Brazilian market. Original files from https://lists.gnucash.org/pipermail/gnucash-br/2016-November/000535.html
`gc2latex <https://github.com/wertarbyte/gc2latex>`__ by wertarbyte (last updated on  <10)
	create pretty Gnucash invoices with LaTeX and Perl
\* `GnuCash-Branch <https://github.com/LiosK/GnuCash-Branch>`__ by LiosK (last updated on  <10)
	GnuCash::Branch - Utilities to implement branch accounting with GnuCash.
\* `gnucash-extensions <https://github.com/tomason/gnucash-extensions>`__ by tomason (last updated on  <10)
	(No description available)
\* `gnucash-monthly-budget-report <https://github.com/mhodapp/gnucash-monthly-budget-report>`__ by mhodapp (last updated on  <10)
	perl program to generate monthly budget reports
\* `GnuCash-MySQL <https://github.com/theochino/GnuCash-MySQL>`__ by theochino (last updated on  <10)
	A MySQL module to Gnu Cash
\* `gnucash-perl <https://github.com/goblin/gnucash-perl>`__ by goblin (last updated on  <10)
	Perl modules for reading and writing the Gnucash XML file
\* `gnucash-quote-sources <https://github.com/tjol/gnucash-quote-sources>`__ by tjol (last updated on  <10)
	Some useful methods to fetch market price data for GnuCash
\* `GnuCash-SQLite <https://github.com/hoekit/GnuCash-SQLite>`__ by hoekit (last updated on  <10)
	A perl module to access GnuCash SQLite files.
\* `GnuCash-SQLite <https://github.com/gitpan/GnuCash-SQLite>`__ by gitpan (last updated on  <10)
	Read-only release history for GnuCash-SQLite
\* `gnucash-summarizer <https://github.com/Nazrax/gnucash-summarizer>`__ by Nazrax (last updated on  <10)
	(No description available)
`gnucash-xml-to-ledger-dat <https://github.com/icyflame/gnucash-xml-to-ledger-dat>`__ by icyflame (last updated on  <10)
	A script to convert GNUCash's XML file to Ledger's dat file
`gnucash2mysql <https://github.com/xaprb/gnucash2mysql>`__ by xaprb (last updated on  <10)
	Gnucash to MySQL export script.
`gnucash2mysql_extras <https://github.com/hmackiernan/gnucash2mysql_extras>`__ by hmackiernan (last updated on  <10)
	Extra scripts and bits for gnucash2mysql
\* `gnuCash_Quote <https://github.com/z-Wind/gnuCash_Quote>`__ by z-Wind (last updated on  <10)
	modify perl\site\lib\Finance\Quote.pm
\* `MoneyDance-GnuCash-Importer <https://github.com/ets/MoneyDance-GnuCash-Importer>`__ by ets (last updated on  <10)
	Script to convert GnuCash data into a native MoneyDance XML file format
`Paypal-csv-to-qif-converter <https://github.com/sonologic/Paypal-csv-to-qif-converter>`__ by sonologic (last updated on  <10)
	Converts paypal .csv to qif for importing in gnucash
\* `perl-gnucash-reader <https://github.com/hoekit/perl-gnucash-reader>`__ by hoekit (last updated on  <10)
	(No description available)
`PerlFinanceQuoteBloomberg <https://github.com/alex314159/PerlFinanceQuoteBloomberg>`__ by alex314159 (last updated on  <10)
	Bloomberg module for the Perl Finance::Quote module (used in particular by GnuCash)
\* `query_gnucash_db <https://github.com/hmackiernan/query_gnucash_db>`__ by hmackiernan (last updated on  <10)
	Perl script to query a MySQL db created by the 'gnucash2mysql' script

.. _Perl6:

Perl6
-----

`perl6-gnucash <https://github.com/eikef/perl6-gnucash>`__ by eikef (last updated on  <10)
	Use gnucash library from Perl 6

.. _R:

R
-

`gnucashAndR <https://github.com/mrop/gnucashAndR>`__ by mrop (last updated on  <10)
	(No description available)
`ShinyBudgetAnalysis <https://github.com/paulheider/ShinyBudgetAnalysis>`__ by paulheider (last updated on  <10)
	A Shiny app (R-based dashboard) that gives insight into your GnuCash budget habits over time.

.. _Roff:

Roff
----

\* `gnucash-docker <https://github.com/rusodavid/gnucash-docker>`__ by rusodavid (last updated on  <10)
	(No description available)

.. _Ruby:

Ruby
----

\* `accounting <https://github.com/freegeek-pdx/accounting>`__ by freegeek-pdx (last updated on  <10)
	accounting utilities for xtuple import and allocation in xtuple and gnucash
\* `arges <https://github.com/isimluk/arges>`__ by isimluk (last updated on  <10)
	Calc roe from gnucash transaction log
`banks-to-gnucash <https://github.com/toniprada/banks-to-gnucash>`__ by toniprada (last updated on  <10)
	Quaterly bank reports in CSV GnuCash-friendly format directly in your email.
`boekhouden-met-gnucash <https://github.com/mauritslamers/boekhouden-met-gnucash>`__ by mauritslamers (last updated on  <10)
	Een Nederlandse handleiding over het boekhouden met GnuCash
\* `cnab2ofx <https://github.com/abinoam/cnab2ofx>`__ by abinoam (last updated on  <10)
	CNAB240 to OFX conversion script
\* `dnbnor2qif <https://github.com/kentdahl/dnbnor2qif>`__ by kentdahl (last updated on  <10)
	dnbnor2qif is a simple tool to help integrate data from the DnBNOR online bank monthly transcripts ("kontoutskrift") to a QIF accepting financial program, i.e. GnuCash.
\* `equity_flow <https://github.com/fernandors87/equity_flow>`__ by fernandors87 (last updated on  <10)
	A personal asset management software
`gnucash-invoice <https://github.com/ixti/gnucash-invoice>`__ by ixti (last updated on  <10)
	Easy to use invoice printer for GnuCash.
\* `gnucash-rb <https://github.com/vbatts/gnucash-rb>`__ by vbatts (last updated on  <10)
	Ruby access to Gnucash SQL database
`gnucash-summarizer <https://github.com/arthurljones/gnucash-summarizer>`__ by arthurljones (last updated on  <10)
	(No description available)
\* `gnucash2bmd <https://github.com/ngiger/gnucash2bmd>`__ by ngiger (last updated on  <10)
	Convert GnuCash CSV files into CSV which can be read by http://www.bmd.com/
`gnucash2ledger <https://github.com/xaviershay/gnucash2ledger>`__ by xaviershay (last updated on  <10)
	Convert GnuCash files to a format supported by the ledger command line application
\* `gnucash_export <https://github.com/alibby/gnucash_export>`__ by alibby (last updated on  <10)
	Export gnucash data to sqlite/ csv
\* `gnucash_getquotes <https://github.com/hubcity/gnucash_getquotes>`__ by hubcity (last updated on  <10)
	(No description available)
\* `nyancash <https://github.com/hanazuki/nyancash>`__ by hanazuki (last updated on  <10)
	Ruby to GnuCash database binding
`rcash <https://github.com/salex/rcash>`__ by salex (last updated on  <10)
	Rails Double Entry Accounting app patterned after GNUCash
`ruby-gnucash <https://github.com/holtrop/ruby-gnucash>`__ by holtrop (last updated on  <10)
	Ruby library for extracting data from GnuCash data files
\* `vfwcash <https://github.com/salex/vfwcash>`__ by salex (last updated on  <10)
	A Ruby CLI application that produces PDF reports from GnuCash

.. _Rust:

Rust
----

`stay-the-course <https://github.com/DavidCain/stay-the-course>`__ by DavidCain (last updated on  <10)
	Lazy portfolio rebalancer for GnuCash users

.. _SQLPL:

SQLPL
-----

\* `gnucash-tools <https://github.com/schoettl/gnucash-tools>`__ by schoettl (last updated on  <10)
	Collection of tools to work with GnuCash efficiently

.. _Scala:

Scala
-----

\* `gnucash-stuff <https://github.com/crankydillo/gnucash-stuff>`__ by crankydillo (last updated on  <10)
	(No description available)
\* `GnuCashExtractor <https://github.com/Winbee/GnuCashExtractor>`__ by Winbee (last updated on  <10)
	Extract data from gnuCash and copy it into an open document spreadsheet
`YNAB4toGnuCashMigrationTool <https://github.com/galbarm/YNAB4toGnuCashMigrationTool>`__ by galbarm (last updated on  <10)
	YNAB 4 to GnuCash Migration Tool

.. _Scheme:

Scheme
------

`bas-report <https://github.com/spandan888/bas-report>`__ by spandan888 (last updated on  <10)
	GST India Report / Business Tax Report
\* `gc-decl-reports <https://github.com/yawaramin/gc-decl-reports>`__ by yawaramin (last updated on  <10)
	GnuCash declarative reports
`gnucash-account-balance-chart <https://github.com/timabell/gnucash-account-balance-chart>`__ by timabell (last updated on  <10)
	account balance line chart for gnucash
\* `gnucash-custom-reports <https://github.com/BenBergman/gnucash-custom-reports>`__ by BenBergman (last updated on  <10)
	(No description available)
`gnucash-multicolumn <https://github.com/daniel-beet/gnucash-multicolumn>`__ by daniel-beet (last updated on  <10)
	Advanced date and text filtering and multicolumn reports
\* `gnucash-paypal-invoice-template <https://github.com/charlesmulder/gnucash-paypal-invoice-template>`__ by charlesmulder (last updated on  <10)
	GnuCash invoice template that resembles a PayPal invoice
`gnucash-reports <https://github.com/dschwen/gnucash-reports>`__ by dschwen (last updated on  <10)
	Custom reports for Gnucash
\* `gnucash-reports <https://github.com/trailbound/gnucash-reports>`__ by trailbound (last updated on  <10)
	Custom set of gnucash reports, currently in development.
\* `gnucash-reports <https://github.com/cnuahs/gnucash-reports>`__ by cnuahs (last updated on  <10)
	Custom reports for use with GnuCash (http://gnucash.org/).
`gnucash-reports <https://github.com/jaminh/gnucash-reports>`__ by jaminh (last updated on  <10)
	Reports for personal finance using gnucash
\* `gnucash-reports <https://github.com/wentzel/gnucash-reports>`__ by wentzel (last updated on  <10)
	Some nice reports for GnuCash
\* `gnucash-statement-table <https://github.com/waldeinburg/gnucash-statement-table>`__ by waldeinburg (last updated on  <10)
	GnuCash report with cash flow over time
\* `gnucashportable <https://github.com/GordCaswell/gnucashportable>`__ by GordCaswell (last updated on  <10)
	GnuCash packaged in PortableApps.com Format
\* `GnuCashReports <https://github.com/wlcasper/GnuCashReports>`__ by wlcasper (last updated on  <10)
	Custom Reports for GnuCash
`ibr-gnc-module <https://github.com/ErwinRieger/ibr-gnc-module>`__ by ErwinRieger (last updated on  <10)
	GnuCash Erweiterungen für deutsche Buchhaltung

.. _Shell:

Shell
-----

\* `AccountsConvertToGnucash <https://github.com/tontako/AccountsConvertToGnucash>`__ by tontako (last updated on  <10)
	Convert Kakeibo(Android Application) CSV exports to QIF format (usable by GnuCash and others) 
`ansible-role-gnucash <https://github.com/alvistack/ansible-role-gnucash>`__ by alvistack (last updated on  <10)
	Ansible Role for GnuCash Installation
\* `archlinux-gnucash-latest <https://github.com/nengxu/archlinux-gnucash-latest>`__ by nengxu (last updated on  <10)
	Archlinux AUR package building scripts for latest Gnucash
\* `docker_gnucash <https://github.com/tkerns1965/docker_gnucash>`__ by tkerns1965 (last updated on  <10)
	(No description available)
\* `docker_gnucash_novnc <https://github.com/tkerns1965/docker_gnucash_novnc>`__ by tkerns1965 (last updated on  <10)
	(No description available)
\* `gnucash-build <https://github.com/hanulhan/gnucash-build>`__ by hanulhan (last updated on  <10)
	(No description available)
\* `gnucash-build-script <https://github.com/z-Wind/gnucash-build-script>`__ by z-Wind (last updated on  <10)
	for ubuntu 
\* `gnucash-csv-import <https://github.com/thomasramapuram/gnucash-csv-import>`__ by thomasramapuram (last updated on  <10)
	(No description available)
\* `gnucash-devel <https://github.com/aur-archive/gnucash-devel>`__ by aur-archive (last updated on  <10)
	(No description available)
\* `gnucash-docker <https://github.com/limitedAtonement/gnucash-docker>`__ by limitedAtonement (last updated on  <10)
	docker image for repeatable gnucash builds.
\* `gnucash-docs <https://github.com/aur-archive/gnucash-docs>`__ by aur-archive (last updated on  <10)
	(No description available)
\* `gnucash-docs-old <https://github.com/yasuakit/gnucash-docs-old>`__ by yasuakit (last updated on  <10)
	Manual and User Guide for Gnucash, the open-source accounting program
\* `gnucash-hbci <https://github.com/aur-archive/gnucash-hbci>`__ by aur-archive (last updated on  <10)
	(No description available)
\* `gnucash-on-debian <https://github.com/rayelnigma/gnucash-on-debian>`__ by rayelnigma (last updated on  <10)
	a set of build scripts to build gnucash using Ninja for faster builds
`gnucash-on-fedora-copr <https://github.com/zhiqinghuang/gnucash-on-fedora-copr>`__ by zhiqinghuang (last updated on  <10)
	A set of build scripts geared towards creating rpm packages for gnucash and gnucash-docs on Fedora's Copr infrastructure. It's currently used to build nightly rpm packages for the maint and master branches intended for testing changes since the last release..
`gnucash-on-flatpak <https://github.com/Gnucash/gnucash-on-flatpak>`__ by Gnucash (last updated on  <10)
	Packaging scripts to generate flatpaks directly from gnucash and gnucash-docs git repositories
`gnucash-on-osx <https://github.com/Gnucash/gnucash-on-osx>`__ by Gnucash (last updated on  <10)
	Gtk-OSX moduleset, gtk-mac-bundler bundles, and ancillary files for creating GnuCash OSX Application Bundle.
`gnucash-on-osx <https://github.com/jralls/gnucash-on-osx>`__ by jralls (last updated on  <10)
	Build GnuCash on OSX without X11
\* `gnucash-python <https://github.com/aur-archive/gnucash-python>`__ by aur-archive (last updated on  <10)
	(No description available)
\* `gnucash-svn <https://github.com/aur-archive/gnucash-svn>`__ by aur-archive (last updated on  <10)
	(No description available)
`gnucash-util-jp <https://github.com/mikkun/gnucash-util-jp>`__ by mikkun (last updated on  <10)
	日本の商慣習下でGnuCashを使うためのツール
`gnucash.AppImage <https://github.com/ecmu/gnucash.AppImage>`__ by ecmu (last updated on  <10)
	AppImage build for gnucash
\* `gnucash.SlackBuild <https://github.com/botzkobg/gnucash.SlackBuild>`__ by botzkobg (last updated on  <10)
	SlackBuild script to compile GnuCash
\* `LittleBudget <https://github.com/kstripp/LittleBudget>`__ by kstripp (last updated on  <10)
	Little Budget Tool for GNUCash
\* `nordea2ofx <https://github.com/nsrosenqvist/nordea2ofx>`__ by nsrosenqvist (last updated on  <10)
	A quick implementation of a converter between Nordea's CSV export to OFX so that it can be imported into various applications, such as Homebank or GnuCash. Only supporting Swedish and my edge cases, please consider improving the script and send a pull request for the changes.
\* `TW5-GNUCash-Assistant <https://github.com/JulioCantarero/TW5-GNUCash-Assistant>`__ by JulioCantarero (last updated on  <10)
	A custom edition of TiddlyWiki5 designed to collect financial information from your banks and export them in QIF format

.. _Swift:

Swift
-----

`cash <https://github.com/cjwirth/cash>`__ by cjwirth (last updated on  <10)
	iOS companion app for GnuCash

.. _TSQL:

TSQL
----

`gnucash-reports <https://github.com/fredzica/gnucash-reports>`__ by fredzica (last updated on  <10)
	Custom reports that use data from gnucash's SQL database
\* `GNUCashProcs <https://github.com/nicholasceliano/GNUCashProcs>`__ by nicholasceliano (last updated on  <10)
	(No description available)

.. _Tcl:

Tcl
---

`pycash <https://github.com/davinirjr/pycash>`__ by davinirjr (last updated on  <10)
	Some Python utilites that GnuCash users may find useful.

.. _TypeScript:

TypeScript
----------

`gnucash-global-importer <https://github.com/klodzack/gnucash-global-importer>`__ by klodzack (last updated on  <10)
	(No description available)
\* `gnucash-graphql <https://github.com/phjardas/gnucash-graphql>`__ by phjardas (last updated on  <10)
	GraphQL Wrapper For GnuCash Ledgers
`GnuCashImporter <https://github.com/nicholasceliano/GnuCashImporter>`__ by nicholasceliano (last updated on  <10)
	(No description available)
\* `v9-geckos-team-07 <https://github.com/chingu-voyages/v9-geckos-team-07>`__ by chingu-voyages (last updated on  <10)
	GeckoCash: A web-based GnuCash clone.

.. _Visual Basic:

Visual Basic
------------

`OneClickToQif <https://github.com/OneClickToQif/OneClickToQif>`__ by OneClickToQif (last updated on  <10)
	OneClickToQIF consists of a set of templates and macros, which are used to export data from your spreadsheets to QIF format, as used by programs such as GnuCash, Money and Quicken. You can use the templates as provided, or adapt your own spreadsheet, so your data is automatically exported to QIF with a single click.

.. _XSLT:

XSLT
----

\* `asciidoc-conversion <https://github.com/codesmythe/asciidoc-conversion>`__ by codesmythe (last updated on  <10)
	Script and tools to convert GnuCash DocBook XML to AsciiDoc
`gnucash-docs <https://github.com/Gnucash/gnucash-docs>`__ by Gnucash (last updated on  <10)
	Documentation for GnuCash Accounting Program.
\* `gnucash-docs <https://github.com/mattig7/gnucash-docs>`__ by mattig7 (last updated on  <10)
	(No description available)
\* `Gnucash-gnucash-docs <https://github.com/jimmymccord/Gnucash-gnucash-docs>`__ by jimmymccord (last updated on  <10)
	(No description available)

.. _Unknown:

Unknown
-------

\* `accounting-plans <https://github.com/jeblad/accounting-plans>`__ by jeblad (last updated on  <10)
	Accounting plans for GnuCash
\* `accounts <https://github.com/sjtug/accounts>`__ by sjtug (last updated on  <10)
	Accounts of SJTUG in GNUCash Format
`accounts_gnucash <https://github.com/Baneeishaque/accounts_gnucash>`__ by Baneeishaque (last updated on  <10)
	(No description available)
\* `an-gnucash <https://github.com/wanjing/an-gnucash>`__ by wanjing (last updated on  <10)
	android app for gnucash
\* `ansible-role-gnucash <https://github.com/wtanaka/ansible-role-gnucash>`__ by wtanaka (last updated on  <10)
	Ansible role for installing gnucash
`bookee <https://github.com/hesy-mzh/bookee>`__ by hesy-mzh (last updated on  <10)
	Account data for GnuCash
`budget <https://github.com/bhagdave/budget>`__ by bhagdave (last updated on  <10)
	My Budget from Gnucash
\* `chloris <https://github.com/honthion/chloris>`__ by honthion (last updated on  <10)
	gnucash项目后台参考 python django
\* `Church-Accounting-Using-GnuCash <https://github.com/leggie/Church-Accounting-Using-GnuCash>`__ by leggie (last updated on  <10)
	Various excel templates containing vba scripts that makes church accounting using the open source accounting tool GnuCash as described in the blog "http://financeandaccountingforchurches.blogspot.in/2012/12/church-accounting-using-gnucash-1.html".  The files in the links mentioned there are hosted in this repository
\* `CICtoGNUcash <https://github.com/jbtruffault/CICtoGNUcash>`__ by jbtruffault (last updated on  <10)
	(No description available)
`commerzbank-csv4gnucash <https://github.com/zanto001/commerzbank-csv4gnucash>`__ by zanto001 (last updated on  <10)
	Tweak CSV exports from commerzbank for importing into GnuCash.
\* `ComptaTest <https://github.com/palric/ComptaTest>`__ by palric (last updated on  <10)
	Exercices programmation python/panda: importation de fichiers comptas bancaires, formatage et importation dans GnuCash
\* `CPA-006-Asap-Cheques <https://github.com/dougransom/CPA-006-Asap-Cheques>`__ by dougransom (last updated on  <10)
	Gnucash Check Configurations to print on Canadian Cheques from ASAP Cheques.
`csv2qif <https://github.com/andreaZHrustichelli/csv2qif>`__ by andreaZHrustichelli (last updated on  <10)
	Python program to convert csv file into a qif file ready to import in GNUCASH
\* `docker-gnucash <https://github.com/mbessler/docker-gnucash>`__ by mbessler (last updated on  <10)
	Containerized GnuCash
\* `docker-gnucash <https://github.com/rainu/docker-gnucash>`__ by rainu (last updated on  <10)
	A gnucash docker image
\* `docker-gnucash <https://github.com/sgalkin/docker-gnucash>`__ by sgalkin (last updated on  <10)
	gnucash docker image with SpiderOakOne integration
\* `docker-mobile-gnucash <https://github.com/au-phiware/docker-mobile-gnucash>`__ by au-phiware (last updated on  <10)
	Docker containers for justinhunt1223/mobilegnucash
`GCtranslate <https://github.com/AshokR/GCtranslate>`__ by AshokR (last updated on  <10)
	GnuCash Translation
\* `GnuCash-3part-check <https://github.com/agh1/GnuCash-3part-check>`__ by agh1 (last updated on  <10)
	A 3-part check format for GnuCash
`gnucash-accounts <https://github.com/ordtrogen/gnucash-accounts>`__ by ordtrogen (last updated on  <10)
	Some Account Hierarchy Templates for GnuCash in Swedish
\* `gnucash-android-master <https://github.com/abdullahwale/gnucash-android-master>`__ by abdullahwale (last updated on  <10)
	(No description available)
\* `gnucash-api <https://github.com/jjuanda/gnucash-api>`__ by jjuanda (last updated on  <10)
	REST APIs for GnuCash files
`gnucash-build-debian <https://github.com/willelop/gnucash-build-debian>`__ by willelop (last updated on  <10)
	Installs in Debian all the required dependencies for building gnucash
\* `gnucash-compose <https://github.com/daveyb/gnucash-compose>`__ by daveyb (last updated on  <10)
	docker-compose file(s) to bring up local gnucash cluster
\* `gnucash-data <https://github.com/anshprat/gnucash-data>`__ by anshprat (last updated on  <10)
	data files for my gnucash encrypted with gpg
\* `gnucash-docker <https://github.com/KaiLemke/gnucash-docker>`__ by KaiLemke (last updated on  <10)
	containerized gnucash 2.6
\* `gnucash-docker <https://github.com/dbcesar/gnucash-docker>`__ by dbcesar (last updated on  <10)
	Dockerfile and docker-compose to install and run gnucash 3.0 from a docker container
\* `gnucash-docs <https://github.com/cygwinports/gnucash-docs>`__ by cygwinports (last updated on  <10)
	Cygwin gnucash-docs packaging
\* `gnucash-fire-tools <https://github.com/KarolOlko/gnucash-fire-tools>`__ by KarolOlko (last updated on  <10)
	Slicing gnucash DB for more insights
`gnucash-guide-asciidoc <https://github.com/codesmythe/gnucash-guide-asciidoc>`__ by codesmythe (last updated on  <10)
	The GnuCash Tutorial and Concept Guide, converted to Asciidoc
\* `gnucash-my_chart_of_accounts <https://github.com/5472qaywsx/gnucash-my_chart_of_accounts>`__ by 5472qaywsx (last updated on  <10)
	my personal chart of accounts for gnucash
`gnucash-pot <https://github.com/fellen/gnucash-pot>`__ by fellen (last updated on  <10)
	Portable Template of GnuCash
\* `gnucash-queries <https://github.com/g2010a/gnucash-queries>`__ by g2010a (last updated on  <10)
	Queries to extract data from Gnucash's database
\* `gnucash-rest <https://github.com/mhitchens/gnucash-rest>`__ by mhitchens (last updated on  <10)
	A Spring Data/Spring REST interface to a gnucash data file
`gnucash-stuff <https://github.com/ajablonski/gnucash-stuff>`__ by ajablonski (last updated on  <10)
	(No description available)
`GnuCash-Tutorials <https://github.com/duguqiubailee/GnuCash-Tutorials>`__ by duguqiubailee (last updated on  <10)
	(No description available)
\* `gnucash-web <https://github.com/djbrown/gnucash-web>`__ by djbrown (last updated on  <10)
	(No description available)
\* `GNUCASH.APP-ERICK-CLEWIS <https://github.com/ErickClewisAccountsdatamoneymarketing/GNUCASH.APP-ERICK-CLEWIS>`__ by ErickClewisAccountsdatamoneymarketing (last updated on  <10)
	USD$ DATABASE OPEN SOURCE DATA
\* `gnucash_auto <https://github.com/torchtarget/gnucash_auto>`__ by torchtarget (last updated on  <10)
	A simple transaction importer for Gnucash
\* `gnucashdeb <https://github.com/twt2/gnucashdeb>`__ by twt2 (last updated on  <10)
	(No description available)
\* `gnucashdockeraws <https://github.com/fervincent/gnucashdockeraws>`__ by fervincent (last updated on  <10)
	(No description available)
\* `GnucashSW <https://github.com/Oldobaba/GnucashSW>`__ by Oldobaba (last updated on  <10)
	(No description available)
`gnucashTelegram <https://github.com/f-angi/gnucashTelegram>`__ by f-angi (last updated on  <10)
	(No description available)
\* `JsCash <https://github.com/rafaelbeckel/JsCash>`__ by rafaelbeckel (last updated on  <10)
	Double entry accounting system inspired by GNUCash
\* `kg7je <https://github.com/twt2/kg7je>`__ by twt2 (last updated on  <10)
	Stephen Butler's Debian Package Files for GnuCash
\* `knab-gnucash-converter <https://github.com/bkrijg/knab-gnucash-converter>`__ by bkrijg (last updated on  <10)
	A python script for converting KNAB bankstatement information files into a suitable gnucash csv import file
\* `lepturus <https://github.com/honthion/lepturus>`__ by honthion (last updated on  <10)
	gnucash项目后台H5 vue
`moflow <https://github.com/msobkow/moflow>`__ by msobkow (last updated on  <10)
	Money Flow is a revisioning of GNU Cash as a web-enabled Spring Tool Suite 4 application set
\* `nordea-csv2qif <https://github.com/martinolsen/nordea-csv2qif>`__ by martinolsen (last updated on  <10)
	Convert Nordea CSV exports to QIF format (usable by GnuCash and others)
`org.gnucash.GnuCash <https://github.com/flathub/org.gnucash.GnuCash>`__ by flathub (last updated on  <10)
	(No description available)
\* `PayPalConvert <https://github.com/rowantree/PayPalConvert>`__ by rowantree (last updated on  <10)
	Convert PayPal csv files to qif for loading into GnuCash
\* `perotis <https://github.com/honthion/perotis>`__ by honthion (last updated on  <10)
	gnucash项目App flutter
\* `rabo2qif <https://github.com/milovanderlinden/rabo2qif>`__ by milovanderlinden (last updated on  <10)
	export mut.txt to qif for gnucash
\* `resource-gnucash-build <https://github.com/hgati/resource-gnucash-build>`__ by hgati (last updated on  <10)
	(No description available)
`Singularity-GNUCash <https://github.com/rgrandin/Singularity-GNUCash>`__ by rgrandin (last updated on  <10)
	Fedora 28 build of GNUCash
\* `splitwise-to-gnucash <https://github.com/yfede/splitwise-to-gnucash>`__ by yfede (last updated on  <10)
	A script to grab transactions from Splitwise and export them in CSV form for import in GnuCash
\* `tk_ansible_gnucash_vscode01 <https://github.com/tkerns1965/tk_ansible_gnucash_vscode01>`__ by tkerns1965 (last updated on  <10)
	(No description available)
\* `Vishal-Ramteke <https://github.com/vishal7788/Vishal-Ramteke>`__ by vishal7788 (last updated on  <10)
	GnuCash Mobile Automation Test
`webcash <https://github.com/turlog/webcash>`__ by turlog (last updated on  <10)
	WebCash is a proxy service that allows connecting to GNUCash databases with REST API.

